@@ -1,6 +1,6 @@
-# -*- coding: utf-8 -*-
 
-version_info = (0, 1, 0)
+
+version_info = (0, 5, 1)
 VERSION = __version__ = '.'.join(map(str, version_info))
 
 """
@@ -16,3 +16,5 @@ await b.copy('a', 'c')
 await b.move('a', 'c')
 """
 
+from async_cow.cow import AsyncCow, ClientCow
+
